@@ -10,7 +10,13 @@
 #include <QScrollArea>
 #include <QVBoxLayout>
 
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
+
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -24,30 +30,34 @@ BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QLis
 {
     Q_UNUSED(args);
 
-    QWidget *widgetContainer = new QWidget();
+    auto widgetContainer = new QWidget();
 
-    QVBoxLayout *containerLayout = new QVBoxLayout(widgetContainer);
+    auto containerLayout = new QVBoxLayout(widgetContainer);
     containerLayout->setContentsMargins(0, 0, 0, 0);
     containerLayout->setSpacing(0);
 
-    auto *metaDataWidget = new Baloo::FileMetaDataWidget();
+    auto metaDataWidget = new Baloo::FileMetaDataWidget();
     metaDataWidget->setItems(properties->items());
     connect(metaDataWidget, &Baloo::FileMetaDataWidget::urlActivated, this, [this](const QUrl &url) {
-        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+        auto job = new KIO::OpenUrlJob(url);
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, properties));
+#else
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, properties));
+#endif
         job->start();
     });
 
     containerLayout->addWidget(metaDataWidget);
     containerLayout->addStretch(1);
 
-    QScrollArea *metaDataArea = new QScrollArea();
+    auto metaDataArea = new QScrollArea();
 
     metaDataArea->setWidget(widgetContainer);
     metaDataArea->setWidgetResizable(true);
     metaDataArea->setFrameShape(QFrame::NoFrame);
 
-    connect(metaDataWidget, &Baloo::FileMetaDataWidget::metaDataRequestFinished, this, [this, metaDataArea, metaDataWidget] {
+    connect(metaDataWidget, &Baloo::FileMetaDataWidget::metaDataRequestFinished, this, [this, metaDataArea] {
         properties->addPage(metaDataArea, i18nc("Tab page with file meta data", "&Details"));
     });
 }
